@@ -9,9 +9,7 @@ from django.db.models.sql.compiler import SQLCompiler
 from django.utils import timezone
 from django.utils.version import get_version_tuple
 
-UpdateFieldsTypeDef = Union[
-    List[str], List["UpsertResult"], List[Union["UpsertResult", str]], None
-]
+UpdateFieldsTypeDef = Union[List[str], List["UpdateField"], List[Union["UpdateField", str]], None]
 
 
 def _psycopg_version():
@@ -364,6 +362,7 @@ def _upsert(
     model_objs: Iterable[models.Model],
     unique_fields: List[str],
     update_fields: UpdateFieldsTypeDef = None,
+    exclude: Union[List[str], None] = None,
     returning: Union[List[str], bool] = False,
     redundant_updates: bool = False,
 ):
@@ -384,11 +383,15 @@ def _upsert(
             perform an expression such as an `F` object on a field when
             it is updated, use the [pgbulk.UpdateField][] class. See
             examples below.
+        exclude: A list of fields to exclude from the upsert. This is useful
+            when `update_fields` is `None` and you want to exclude fields from
+            being updated. This is additive to the `unique_fields` list.
         returning: If True, returns all fields. If a list,
             only returns fields in the list.
         redundant_updates: Don't perform an update
             if all columns are identical to the row in the database.
     """
+    exclude = exclude or []
     queryset = queryset if isinstance(queryset, models.QuerySet) else queryset.objects.all()
 
     # Populate automatically generated fields in the rows like date times
@@ -396,7 +399,7 @@ def _upsert(
 
     # Sort the rows to reduce the chances of deadlock during concurrent upserts
     model_objs = _sort_by_unique_fields(queryset, model_objs, unique_fields)
-    update_fields = _get_update_fields(queryset, update_fields, exclude=unique_fields)
+    update_fields = _get_update_fields(queryset, update_fields, exclude=[*exclude, *unique_fields])
 
     return _fetch(
         queryset,
@@ -412,6 +415,7 @@ def update(
     queryset: Union[Type[models.Model], models.QuerySet],
     model_objs: Iterable[models.Model],
     update_fields: Union[List[str], None] = None,
+    exclude: Union[List[str], None] = None,
 ) -> None:
     """
     Performs a bulk update.
@@ -421,6 +425,9 @@ def update(
         model_objs: Model object values to use for the update
         update_fields: A list of fields on the
             model objects to update. If `None`, all fields will be updated.
+        exclude: A list of fields to exclude from the update. This is useful
+            when `update_fields` is `None` and you want to exclude fields from
+            being updated.
 
     Note:
         Model signals such as `post_save` are not emitted.
@@ -444,7 +451,7 @@ def update(
     queryset = queryset if isinstance(queryset, models.QuerySet) else queryset.objects.all()
     connection = connections[queryset.db]
     model = queryset.model
-    update_fields = _get_update_fields(queryset, update_fields)
+    update_fields = _get_update_fields(queryset, update_fields, exclude)
 
     # Sort the model objects to reduce the likelihood of deadlocks
     model_objs = sorted(model_objs, key=lambda obj: obj.pk)
@@ -520,6 +527,7 @@ async def aupdate(
     queryset: Union[Type[models.Model], models.QuerySet],
     model_objs: Iterable[models.Model],
     update_fields: Union[List[str], None] = None,
+    exclude: Union[List[str], None] = None,
 ) -> None:
     """
     Perform an asynchronous bulk update.
@@ -531,7 +539,7 @@ async def aupdate(
         a `sync_to_async` wrapper. It does not yet use an asynchronous database
         driver but will in the future.
     """
-    return await sync_to_async(update)(queryset, model_objs, update_fields)
+    return await sync_to_async(update)(queryset, model_objs, update_fields, exclude)
 
 
 def upsert(
@@ -540,6 +548,7 @@ def upsert(
     unique_fields: List[str],
     update_fields: UpdateFieldsTypeDef = None,
     *,
+    exclude: Union[List[str], None] = None,
     returning: Union[List[str], bool] = False,
     redundant_updates: bool = False,
 ) -> UpsertResult:
@@ -559,6 +568,9 @@ def upsert(
             the objects that don't exist. If `None`, all fields will be updated.
             If you want to perform an expression such as an `F` object on a field when
             it is updated, use the [pgbulk.UpdateField][] class. See examples below.
+        exclude: A list of fields to exclude from the upsert. This is useful
+            when `update_fields` is `None` and you want to exclude fields from
+            being updated. This is additive to the `unique_fields` list.
         returning: If True, returns all fields. If a list, only returns fields
             in the list. If False, do not return results from the upsert.
         redundant_updates: Perform an update
@@ -658,6 +670,7 @@ def upsert(
         unique_fields,
         update_fields=update_fields,
         returning=returning,
+        exclude=exclude,
         redundant_updates=redundant_updates,
     )
 
@@ -669,6 +682,7 @@ async def aupsert(
     update_fields: UpdateFieldsTypeDef = None,
     *,
     returning: Union[List[str], bool] = False,
+    exclude: Union[List[str], None] = None,
     redundant_updates: bool = False,
 ) -> UpsertResult:
     """
@@ -687,5 +701,6 @@ async def aupsert(
         unique_fields,
         update_fields,
         returning=returning,
+        exclude=exclude,
         redundant_updates=redundant_updates,
     )
